@@ -21,8 +21,7 @@
 
 #include <AkonadiWidgets/CollectionDialog>
 
-namespace NoteShared
-{
+namespace NoteShared {
 class SelectedNotefolderDialog : public Akonadi::CollectionDialog
 {
     Q_OBJECT
